import type { ParallaxScrollerListenerParams } from "./types.js";
interface InitParams {
    listener?: (params: ParallaxScrollerListenerParams) => void;
    root?: HTMLElement;
}
/**
 * Parallax Scroller initializer.
 *
 * 1. It iterates through all HTML elements with "data-scroll" attribute and
 * parses `data-{$percent}p` properties into keyframes. Than it takes first
 * keyframe and applies initial styles to the elements.
 *
 * $percent is the scrolling percentage of the viewport height, it can start
 * from 0p to infinite number, i.e 300p means 300% or 3 times the viewport
 * height.
 *
 * 2. Based on the maximum keyframe value, it sets the height of body element.
 *
 * 3. Starts the loop, which re-renders elements positions based on scroll
 * position.
 *
 * data-scroll attribute can take a name of an element for debugging
 * convenience.
 */
export declare const init: ({ listener, root }: InitParams) => void;
/**
 * Parallax Scroller destroyer.
 *
 * Resets scroller state, clears styling side effects to DOM and removes
 * listeners
 */
export declare const destroy: () => void;
export {};
