import { Keyframe, type ParallaxScrollerElement } from "./types";
/**
 * @typedef {Object} Tweening
 * @property {Keyframe} from starting keyframe point
 * @property {Keyframe} to ending keyframe point
 */
/**
 * Convert element props into style keyframes.
 *
 * @param {KeyframeStyles[]} props Array of key-values objects where key is a
 * CSS property and value is a value of this property.
 * @param {ParallaxScrollerElement} element
 * @param {number} constant Signifies scroll percentage
 *
 * @returns void
 */
export declare const setElementKeyframes: (props: Array<Record<string, string>>, element: ParallaxScrollerElement, constant: number) => void;
/**
 * Sort keyframes by percentage to apply initial styles correctly
 * @private
 *
 * @param {ParallaxScrollerElement} element
 */
export declare const sortKeyframes: (element: ParallaxScrollerElement) => void;
/**
 * Applies style for a specific frame.
 *
 * @param {ParallaxScrollerElement} element - Target element.
 * @param {number} point - Current scroll point.
 * @param {string} cssProp - CSS property name.
 * @param {Tweening} tweening - Object with `from` and `to` keyframes.
 *
 * @returns {boolean} True if the frame was applied, false otherwise.
 */
export declare const applyFrameStyle: (element: ParallaxScrollerElement, point: number, cssProp: string, { from, to }: {
    from: Keyframe;
    to?: Keyframe | undefined;
}) => boolean;
/**
 * Apply styles with calculated scroll percentage to the given
 * ParallaxScrollerElement.
 * @private
 *
 * @param {ParallaxScrollerElement} element
 * @param {number} percent Scrolled percentage relative to full viewport height
 *
 * @returns void
 */
export declare const setStylesForKeyframes: (element: ParallaxScrollerElement, percent: number) => void;
