/**
 * @typedef {Object} KeyframeStyles
 * @property {string} - CSS property name
 * @property {string} - CSS property value
 */
/**
 * @typedef {Object} ParsedStyle
 * @property {number} rule CSS property
 * @property {string} template CSS style with numeric values replaced with {?}
 * @property {number[]} values Array of numeric values of CSS style
 */
/**
 * Extract numeric values from CSS styles and replace the with a placeholder.
 * @private
 *
 * @param {KeyframeStyles} prop Key-value object where key is a CSS property and
 * value is its value, i.e:
 *
 * - {transform: 'translate(300px, 0) rotate(10deg)'}
 * - {opacity: '0'}
 * - {display: 'none'}
 *
 * @returns {ParsedStyle} Parsed style object, i.e:
 *
 * - {rule: 'transform', template: 'translate({?}px, {?}) rotate({?}deg)', values: [300, 0, 10]}
 * - {rule: 'opacity', template: '{?}', values: [0]}
 * - {rule: 'display', template: 'none', values: []}
 */
export declare const parseProp: (prop: Record<string, string>) => {
    rule: null;
    template: string;
    values: never[];
} | {
    rule: string;
    template: string;
    values: number[];
};
/**
 * Parse CSS styles, provided by `data-{$percent}p` properties into array of
 * key-value pairs.
 * @private
 *
 * @param {string} attrValue A string with one or multiple styles, separated by
 * semicolon (;), i.e:
 *
 * - transform: translate(300px, 0) rotate(10deg); opacity:0;
 * - display: none;
 *
 *
 * @returns {KeyframeStyles[]} Array of key-values objects where key is a CSS
 * property and value is a value of this property, i.e:
 *
 * - [{transform: 'translate(300px, 0) rotate(10deg)'}, {opacity: '0'}]
 * - [{display: 'none'}]
 */
export declare const parseKeyframeStyles: (attrValue: string) => Record<string, string>[];
