/**
 * Debounce function.
 */
export declare const debounce: <T extends (...args: Array<unknown>) => unknown>(func: T, wait: number) => (...args: Parameters<T>) => void;
/**
 * Calculate page percent scrolled.
 * @private
 */
export declare const calculatePageScrollPercent: () => number;
/**
 * Calculate CSS value delta based on scroll percentage and add it to initial
 * @private
 *
 * @param {number} from Starting value from `data-{$percent}p` property
 * @param {number} to Ending value from next `data-{$percent}p` property
 * @param {number} progress Relative scroll percentage between "from" and "to"
 *
 * @returns {number} Current CSS value, relative to the "from" point
 */
export declare const interpolate: (from: number, to: number, progress: number) => number;
/**
 * Replace placeholders in CSS styled with interpolated values, based on
 * relative percentage scrolled between keyframes.
 * @private
 *
 * @param {string} template CSS value with placeholders, i.e:
 *
 * -translate({?}px, {?}px)
 *
 * @param {number[]} values Array of values for current scroll position, i. e:
 *
 * - [204.5324427480916, -68.17748091603053]
 *
 * @returns {string} Valid CSS value, i.e:
 *
 * - translate(204.5324427480916px, -68.17748091603053px)
 */
export declare const substituteStyleValue: (template: string, values: Array<number>) => string;
